OiRA

Help

1. Priprava
2. Vključevanje
3. Identifikacija + Ocena
4. Načrt ukrepov
5. Poročilo
6. Status 0%

# Poročanje

Ko ste končali z identifikacijo vseh tveganj v vaši organizaciji in ste ustvarili načrt ukrepov, lahko ustvarite poročilo, ki bo vsebovalo vse vaše rezultate in predloge.

Shrani in nadaljuj

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More